#ifndef BOOST_FLOAT_CUSTOM_HEADER
#define BOOST_FLOAT_CUSTOM_HEADER

#include <boost/multiprecision/number.hpp>

// Headers required for Boost.Math integration:
#include <boost/math/special_functions/gamma.hpp>
#include <boost/math/special_functions/bessel.hpp>

using namespace boost::multiprecision;
using namespace boost::math;

namespace boostgsoc2013{
namespace multiprecision{
namespace backends{

template<class T>
class float_mp;

} //namespace

namespace backends{

template<class T>
class float_mp{
private:
	T a, b;
public:
	float_mp(T x, T y){
		a = x;
		b = y;
	}
	float_mp(T x){
		a = x;
	}
	T sinc();
	T gamma();
	T bessel_1();
	T neumann();
};

template<class T>
inline T float_mp<T>::sinc()
{
	T temp = sin(a)/a;
	if (temp > std::numeric_limits<T>::epsilon())
		return temp;
	else
		return 1;
}

template<class T>
inline T float_mp<T>::gamma()
{
	T temp = tgamma(a);
	return temp;
}

template<class T>
inline T float_mp<T>::bessel_1()
{
	T temp = cyl_bessel_j(a, b);
	return temp;
}

template<class T>
inline T float_mp<T>::neumann()
{
	T temp = cyl_neumann(a, b);
	return temp;
}

}//backends namespace

using boost::multiprecision::backends::cpp_dec_float;
typedef number<cpp_dec_float<80> > cpp_dec_float_75;

}//multiprecision namespace
}//boostgsoc namespace

#endif
