#define BOOST_TEST_MODULE floatmp

#include <sstream>
#include <string>
#include <iostream>
#include <iomanip>

#include <boost/test/included/unit_test.hpp>
#include <boost/multiprecision/cpp_dec_float.hpp>

#include <sample_use_boost_float.hpp>

using namespace std;
using namespace boostgsoc2013::multiprecision::backends;

BOOST_AUTO_TEST_CASE( my_test_float_mp )
{
	using boostgsoc2013::multiprecision::cpp_dec_float_75;

	float_mp<cpp_dec_float_75> o1(0);
	float_mp<cpp_dec_float_75> o2(5);
	float_mp<cpp_dec_float_75> o3(4, 2);
	float_mp<cpp_dec_float_75> o4(10, 1);

	//temp variables
	string comp_res;
	ostringstream s_sinc, s_gamma, s_bessel, s_neumann;
	cpp_dec_float_75 res;

	res = o1.sinc();
	s_sinc
		<< std::setprecision(std::numeric_limits<cpp_dec_float_75>::digits10)
		<< res;
	comp_res = s_sinc.str();
	if ( comp_res != "1"){
		BOOST_ERROR("Sinc function test failed");
	}

	res = o2.gamma();
	s_gamma
		<<  std::setprecision(std::numeric_limits<cpp_dec_float_75>::digits10)
		<< res;
	comp_res = s_gamma.str();
    if (comp_res != "24" ){
    	BOOST_ERROR("Gamma function test failed");
    }

    res = o3.bessel_1();
    s_bessel
    	<< std::setprecision(std::numeric_limits<cpp_dec_float_75>::digits10)
    	<< res;
    comp_res = s_bessel.str();
    if ( comp_res != "0.033995719807568434145759211288531044714832968346312864600529511473904443739170845"){
    	BOOST_ERROR("Bessel function test failed");
    }

    res = o4.neumann();
	s_neumann
		<< std::setprecision(std::numeric_limits<cpp_dec_float_75>::digits10)
		<< res;
	comp_res = s_neumann.str();
    if ( comp_res != "-121618014.2786891892881304266679711452886238303093652646152888800082517137641151"){
    	BOOST_ERROR("Neumann function test failed");
    }
}

